<?php

namespace Drupal\simple_popup_blocks\Form;

use Drupal\Core\Url;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\simple_popup_blocks\SimplePopupBlocksStorage;
use Drupal\Core\Access\AccessResult;

/**
 * Form to add a database entry, with all the interesting fields.
 */
class SimplePopupBlocksEditForm extends SimplePopupBlocksAddForm {

  use StringTranslationTrait;
  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'simple_popup_blocks_edit_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $first = NULL) {
    // Query for items to display.
    $entry = SimplePopupBlocksStorage::load($first);
    // Tell the user if there is nothing to display.
    if (empty($entry)) {
      $form['no_values'] = [
        '#value' => t('No entries exist in the table simple_popup_blocks table.'),
      ];
      return $form;
    }
    $entry = $entry[0];

    $form = parent::buildForm($form, $form_state);
    $form['status'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable this as popup.'),
      '#default_value' => $entry->status,
      '#weight' => -99,
    ];
    $form['type']['#default_value'] = $entry->type;
    $form['block_list']['#default_value'] = $entry->identifier;
    $form['custom_css']['#default_value'] = $entry->identifier;
    $form['css_selector']['#default_value'] = $entry->css_selector;
    $form['layout']['#default_value'] = $entry->layout;
    $form['minimize']['#default_value'] = $entry->minimize;
    $form['close']['#default_value'] = $entry->close;
    $form['escape']['#default_value'] = $entry->escape;
    $form['overlay']['#default_value'] = $entry->overlay;
    $form['trigger_method']['#default_value'] = $entry->trigger_method;
    $form['trigger_selector']['#default_value'] = $entry->trigger_selector;
    $form['delay']['#default_value'] = $entry->delay;

    $block_id = str_replace('_', '-', $entry->identifier);
    $modal_class = "." . $block_id . "-modal";
    $modal_close_class = "." . $block_id . "-modal-close";
    $modal_minimize_class = "." . $block_id . "-modal-minimize";
    $modal_minimized_class = "." . $block_id . "-modal-minimized";
    $css_selector = '#';
    if ($entry->type) {
      $css_selector = '.';
    }
    $form['adjustments']['#description'] = 'Use the following css selectors to adjust the popup positions.';

    $rows = [
      0 => ['Parent', $css_selector . $block_id],
      1 => ['Modal class', $modal_class],
      2 => ['Modal close class', $modal_close_class],
      3 => ['Modal minimize class', $modal_minimize_class],
      4 => ['Modal minimized class', $modal_minimized_class],
    ];

    $form['adjustments']['table'] = [
      '#type' => 'table',
      '#rows' => $rows,
      '#empty' => t('No results found'),
    ];

    // Set a value by key.
    $form_state->set('simple_popup_blocks_id', $first);
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    // Verify that the user is logged-in.
    // if ($this->currentUser->isAnonymous()) {
    //   $form_state->setError($form['add'], $this->t('You must be logged in to add values to the database.'));
    // }
    // // Confirm that age is numeric.
    // if (!intval($form_state->getValue('age'))) {
    //   $form_state->setErrorByName('age', $this->t('Age needs to be a number'));
    // }.
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Get a value by key.
    $first = $form_state->get('simple_popup_blocks_id');
    if ($form_state->getValue('type') == 0) {
      $identifier = $form_state->getValue('block_list');
    }
    else {
      $identifier = $form_state->getValue('custom_css');
    }
    // Save the submitted entry.
    $entry = [
      'pid' => $first,
      'identifier' => $identifier,
      'type' => $form_state->getValue('type'),
      'css_selector' => $form_state->getValue('css_selector'),
      'layout' => $form_state->getValue('layout'),
      'width' => $form_state->getValue('width'),
      'overlay' => $form_state->getValue('overlay'),
      'trigger_method' => $form_state->getValue('trigger_method'),
      'trigger_selector' => $form_state->getValue('trigger_selector'),
      'escape' => $form_state->getValue('escape'),
      'delay' => $form_state->getValue('delay'),
      'minimize' => $form_state->getValue('minimize'),
      'close' => $form_state->getValue('close'),
      'status' => $form_state->getValue('status'),
    ];
    $return = SimplePopupBlocksStorage::update($entry);
    if ($return) {
      drupal_set_message($this->t('Popup settings has been updated Successfully.'));
      $url = Url::fromRoute('simple_popup_blocks.manage');
      $form_state->setRedirectUrl($url);
    }
    else {
      drupal_set_message($this->t('Error while creating.'), 'error');
    }
  }

  /**
   * Checks access for a specific request.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Run access checks for this account.
   */
  public function access() {
    // Check permissions and combine that with any custom access checking needed. Pass forward
    // parameters from the route and/or request as needed.
    return AccessResult::allowed();
  }

}
